imodels.tree API documentation
Description: Generic class for models that take the form of a tree of rules.

# Module `imodels.tree`

Generic class for models that take the form of a tree of rules.

Expand source code

    '''Generic class for models that take the form of a tree of rules.
    '''

## Sub-modules

`imodels.tree.c45_tree`
`imodels.tree.cart_ccp`
`imodels.tree.cart_wrapper`
`imodels.tree.gosdt`
`imodels.tree.iterative_random_forest`

  Repeatedly fit random forest, giving features with high importance a higher chance of being selected.

`imodels.tree.saps`
`imodels.tree.shrunk_tree`